@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getCloudXRecv(vmanage, deviceId):
     """
     Get CloudExpress routes received list
@@ -14,8 +11,8 @@ def getCloudXRecv(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/cloudx?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/cloudx?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLinkList(vmanage, state):
     """
@@ -30,8 +27,8 @@ def getLinkList(vmanage, state):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/links?state={state}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/links?state={state}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getMcastAdvt(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getMcastAdvt(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/mcastautodiscoveradvt?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/mcastautodiscoveradvt?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getMcastRecv(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getMcastRecv(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/mcastautodiscoverrecv?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/mcastautodiscoverrecv?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getMcastRoutesAdvt(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getMcastRoutesAdvt(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/mcastroutesadvt?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/mcastroutesadvt?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getMcastRoutesRecv(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getMcastRoutesRecv(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/mcastroutesrecv?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/mcastroutesrecv?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSessionList(vmanage, deviceId):
     """
@@ -110,8 +107,8 @@ def getSessionList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/peers?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/peers?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getAdvRoutesList(vmanage, deviceId):
     """
@@ -126,8 +123,8 @@ def getAdvRoutesList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/routes/advertised?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/routes/advertised?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getAdvRoutesListV6(vmanage, deviceId):
     """
@@ -142,8 +139,8 @@ def getAdvRoutesListV6(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/routes/advertised/ompIpv6?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/routes/advertised/ompIpv6?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRcvdRouteList(vmanage, deviceId):
     """
@@ -158,8 +155,8 @@ def getRcvdRouteList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/routes/received?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/routes/received?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRcvdRouteListVv6(vmanage, deviceId):
     """
@@ -174,8 +171,8 @@ def getRcvdRouteListVv6(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/routes/received/ompIpv6?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/routes/received/ompIpv6?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getServices(vmanage, deviceId):
     """
@@ -190,8 +187,8 @@ def getServices(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/services?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/services?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDeviceStatus(vmanage):
     """
@@ -205,8 +202,8 @@ def getDeviceStatus(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/status"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/status"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSummary(vmanage, deviceId):
     """
@@ -221,8 +218,8 @@ def getSummary(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/summary?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/summary?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncSessionList(vmanage, deviceId):
     """
@@ -237,8 +234,8 @@ def getSyncSessionList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/synced/peers?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/synced/peers?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getAdvTlocsList(vmanage, deviceId):
     """
@@ -253,8 +250,8 @@ def getAdvTlocsList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/tlocs/advertised?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/tlocs/advertised?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRcvdTlocsList(vmanage, deviceId):
     """
@@ -269,6 +266,6 @@ def getRcvdTlocsList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/omp/tlocs/received?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/omp/tlocs/received?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
